# libpythonpro
Módulo para exemplificação de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projeto de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://app.travis-ci.com/JPS-TechEad/libpythonpro.svg?branch=main)](https://app.travis-ci.com/JPS-TechEad/libpythonpro)

Suportada a versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bim/activate
pip install -r requirements-dev.txt
```
Para conferir qualidade de código:

```console
flake8

````

Tópicos a serem abordados:

1. Git
2. Virtualenv
3. pip